@@ -33,7 +33,7 @@
  * getPublicId:
  * @ctx: the user data (XML parser context)
  *
- * Return the public ID e.g. "-//SGMLSOURCE//DTD DEMO//EN"
+ * Provides the public ID e.g. "-//SGMLSOURCE//DTD DEMO//EN"
  *
  * Returns a xmlChar *
  */
@@ -48,7 +48,7 @@ getPublicId(void *ctx ATTRIBUTE_UNUSED)
  * getSystemId:
  * @ctx: the user data (XML parser context)
  *
- * Return the system ID, basically URL or filename e.g.
+ * Provides the system ID, basically URL or filename e.g.
  * http://www.sgmlsource.com/dtds/memo.dtd
  *
  * Returns a xmlChar *
@@ -64,7 +64,7 @@ getSystemId(void *ctx)
  * getLineNumber:
  * @ctx: the user data (XML parser context)
  *
- * Return the line number of the current parsing point.
+ * Provide the line number of the current parsing point.
  *
  * Returns an int
  */
@@ -79,7 +79,7 @@ getLineNumber(void *ctx)
  * getColumnNumber:
  * @ctx: the user data (XML parser context)
  *
- * Return the column number of the current parsing point.
+ * Provide the column number of the current parsing point.
  *
  * Returns an int
  */
@@ -520,8 +520,8 @@ attributeDecl(void *ctx, const xmlChar *elem, const xmlChar *fullname,
     }
     if (ctxt->vctxt.valid == 0)
 	ctxt->valid = 0;
-    if (ctxt->validate && ctxt->wellFormed &&
-        ctxt->myDoc && ctxt->myDoc->intSubset)
+    if ((attr != NULL) && (ctxt->validate) && (ctxt->wellFormed) &&
+        (ctxt->myDoc != NULL) && (ctxt->myDoc->intSubset != NULL))
 	ctxt->valid &= xmlValidateAttributeDecl(&ctxt->vctxt, ctxt->myDoc,
 	                                        attr);
     if (prefix != NULL)
@@ -795,18 +795,20 @@ endDocument(void *ctx)
 }
 
 /**
- * attribute:
+ * my_attribute:
  * @ctx: the user data (XML parser context)
  * @fullname:  The attribute name, including namespace prefix
  * @value:  The attribute value
+ * @prefix: the prefix on the element node
  *
  * Handle an attribute that has been read by the parser.
  * The default handling is to convert the attribute into an
  * DOM subtree and past it in a new xmlAttr element added to
  * the element.
  */
-void
-attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
+static void
+my_attribute(void *ctx, const xmlChar *fullname, const xmlChar *value,
+	     const xmlChar *prefix)
 {
     xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
     xmlAttrPtr ret;
@@ -847,6 +849,8 @@ attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
     if ((!ctxt->html) && (ns == NULL) &&
         (name[0] == 'x') && (name[1] == 'm') && (name[2] == 'l') &&
         (name[3] == 'n') && (name[4] == 's') && (name[5] == 0)) {
+	xmlNsPtr nsret;
+
 	if (value[0] != 0) {
 	    xmlURIPtr uri;
 
@@ -866,7 +870,16 @@ attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
 	}
 
 	/* a default namespace definition */
-	xmlNewNs(ctxt->node, value, NULL);
+	nsret = xmlNewNs(ctxt->node, value, NULL);
+
+	/*
+	 * Validate also for namespace decls, they are attributes from
+	 * an XML-1.0 perspective
+	 */
+        if (nsret != NULL && ctxt->validate && ctxt->wellFormed &&
+	    ctxt->myDoc && ctxt->myDoc->intSubset)
+	    ctxt->valid &= xmlValidateOneNamespace(&ctxt->vctxt, ctxt->myDoc,
+					   ctxt->node, prefix, nsret, value);
 	if (name != NULL) 
 	    xmlFree(name);
 	if (nval != NULL)
@@ -876,23 +889,24 @@ attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
     if ((!ctxt->html) &&
 	(ns != NULL) && (ns[0] == 'x') && (ns[1] == 'm') && (ns[2] == 'l') &&
         (ns[3] == 'n') && (ns[4] == 's') && (ns[5] == 0)) {
-	/*
-	 * Validate also for namespace decls, they are attributes from
-	 * an XML-1.0 perspective
-	 TODO ... doesn't map well with current API
-        if (ctxt->validate && ctxt->wellFormed &&
-	    ctxt->myDoc && ctxt->myDoc->intSubset)
-	    ctxt->valid &= xmlValidateOneAttribute(&ctxt->vctxt, ctxt->myDoc,
-					       ctxt->node, ret, value);
-	 */
+	xmlNsPtr nsret;
+
 	if (value[0] == 0) {
 	    if ((ctxt->sax != NULL) && (ctxt->sax->error != NULL))
 		ctxt->sax->error(ctxt->userData, 
 		     "Empty namespace name for prefix %s\n", name);
 	}
 	/* a standard namespace definition */
-	xmlNewNs(ctxt->node, value, name);
+	nsret = xmlNewNs(ctxt->node, value, name);
 	xmlFree(ns);
+	/*
+	 * Validate also for namespace decls, they are attributes from
+	 * an XML-1.0 perspective
+	 */
+        if (nsret != NULL && ctxt->validate && ctxt->wellFormed &&
+	    ctxt->myDoc && ctxt->myDoc->intSubset)
+	    ctxt->valid &= xmlValidateOneNamespace(&ctxt->vctxt, ctxt->myDoc,
+					   ctxt->node, prefix, nsret, value);
 	if (name != NULL) 
 	    xmlFree(name);
 	if (nval != NULL)
@@ -907,7 +921,7 @@ attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
     }
 
     /* !!!!!! <a toto:arg="" xmlns:toto="http://toto.com"> */
-    ret = xmlNewNsProp(ctxt->node, namespace, name, NULL);
+    ret = xmlNewNsPropEatName(ctxt->node, namespace, name, NULL);
 
     if (ret != NULL) {
         if ((ctxt->replaceEntities == 0) && (!ctxt->html)) {
@@ -984,12 +998,27 @@ attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
 
     if (nval != NULL)
 	xmlFree(nval);
-    if (name != NULL) 
-	xmlFree(name);
     if (ns != NULL) 
 	xmlFree(ns);
 }
 
+/**
+ * attribute:
+ * @ctx: the user data (XML parser context)
+ * @fullname:  The attribute name, including namespace prefix
+ * @value:  The attribute value
+ *
+ * Handle an attribute that has been read by the parser.
+ * The default handling is to convert the attribute into an
+ * DOM subtree and past it in a new xmlAttr element added to
+ * the element.
+ */
+void
+attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
+{
+    my_attribute(ctx, fullname, value, NULL);
+}
+
 /*
  * xmlCheckDefaultedAttributes:
  *
@@ -1194,7 +1223,7 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
      *        attributes parsing, since local namespace can be defined as
      *        an attribute at this level.
      */
-    ret = xmlNewDocNode(ctxt->myDoc, NULL, name, NULL);
+    ret = xmlNewDocNodeEatName(ctxt->myDoc, NULL, name, NULL);
     if (ret == NULL) return;
     if (ctxt->myDoc->children == NULL) {
 #ifdef DEBUG_SAX_TREE
@@ -1248,7 +1277,7 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
     }
 
     /*
-     * process all the attributes whose name start with "xml"
+     * process all the attributes whose name start with "xmlns"
      */
     if (atts != NULL) {
         i = 0;
@@ -1256,8 +1285,9 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 	value = atts[i++];
 	if (!ctxt->html) {
 	    while ((att != NULL) && (value != NULL)) {
-		if ((att[0] == 'x') && (att[1] == 'm') && (att[2] == 'l'))
-		    attribute(ctxt, att, value);
+		if ((att[0] == 'x') && (att[1] == 'm') && (att[2] == 'l') &&
+		    (att[3] == 'n') && (att[4] == 's'))
+		    my_attribute(ctxt, att, value, prefix);
 
 		att = atts[i++];
 		value = atts[i++];
@@ -1302,7 +1332,8 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 	    }
 	} else {
 	    while ((att != NULL) && (value != NULL)) {
-		if ((att[0] != 'x') || (att[1] != 'm') || (att[2] != 'l'))
+		if ((att[0] != 'x') || (att[1] != 'm') || (att[2] != 'l') ||
+		    (att[3] != 'n') || (att[4] != 's'))
 		    attribute(ctxt, att, value);
 
 		/*
@@ -1332,8 +1363,6 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 
     if (prefix != NULL)
 	xmlFree(prefix);
-    if (name != NULL)
-	xmlFree(name);
 
 }
 
