@@ -240,7 +240,7 @@ struct _xmlElementContent {
     struct _xmlElementContent *c1;	/* first child */
     struct _xmlElementContent *c2;	/* second child */
     struct _xmlElementContent *parent;	/* parent */
-    const xmlChar             *prefix;	/* Element name */
+    const xmlChar             *prefix;	/* Namespace prefix */
 };
 
 /**
@@ -839,7 +839,7 @@ int		xmlSaveFile		(const char *filename,
 int		xmlSaveFormatFile	(const char *filename,
 					 xmlDocPtr cur,
 					 int format);
-void		xmlNodeDump		(xmlBufferPtr buf,
+int		xmlNodeDump		(xmlBufferPtr buf,
 					 xmlDocPtr doc,
 					 xmlNodePtr cur,
 					 int level,
