@@ -79,11 +79,6 @@
 #endif
 #include <libxml/globals.h>
 
-#ifdef VMS
-#define xmlRegisterDefaultInputCallbacks xmlRegisterDefInputCallbacks
-#define xmlRegisterDefaultOutputCallbacks xmlRegisterDefOutputCallbacks
-#endif
-
 /* #define VERBOSE_FAILURE */
 /* #define DEBUG_EXTERNAL_ENTITIES */
 /* #define DEBUG_INPUT */
@@ -140,7 +135,7 @@ static int xmlOutputCallbackInitialized = 0;
 
 
 /**
- * xmlNormalizeWindowsPath
+ * xmlNormalizeWindowsPath:
  * @path:  a windows path like "C:/foo/bar"
  *
  * Normalize a Windows path to make an URL from it
@@ -251,7 +246,7 @@ xmlCleanupOutputCallbacks(void)
  ************************************************************************/
 
 /**
- * xmlCheckFilename
+ * xmlCheckFilename:
  * @path:  the path to check
  *
  * function checks to see if @path is a valid source
@@ -466,6 +461,8 @@ xmlFileWrite (void * context, const char * buffer, int len) {
  * @context:  the I/O context
  *
  * Close an I/O channel
+ *
+ * Returns 0 or -1 in case of error
  */
 int
 xmlFileClose (void * context) {
@@ -1038,7 +1035,7 @@ xmlIOHTTPOpen (const char *filename) {
 }
 
 /**
- * xmlIOHTTPOpenW
+ * xmlIOHTTPOpenW:
  * @post_uri:  The destination URI for the document
  * @compression:  The compression desired for the document.
  *
@@ -1181,6 +1178,8 @@ xmlIOHTTPWrite( void * context, const char * buffer, int len ) {
  * @context:  the I/O context
  *
  * Close an HTTP I/O channel
+ *
+ * Returns 0
  */
 int
 xmlIOHTTPClose (void * context) {
@@ -1401,6 +1400,8 @@ xmlIOFTPRead(void * context, char * buffer, int len) {
  * @context:  the I/O context
  *
  * Close an FTP I/O channel
+ *
+ * Returns 0
  */
 int
 xmlIOFTPClose (void * context) {
@@ -1465,11 +1466,7 @@ xmlRegisterOutputCallbacks(xmlOutputMatchCallback matchFunc,
  * Registers the default compiled-in I/O handlers.
  */
 void
-#ifdef VMS
-xmlRegisterDefInputCallbacks
-#else
 xmlRegisterDefaultInputCallbacks
-#endif
 (void) {
     if (xmlInputCallbackInitialized)
 	return;
@@ -1499,11 +1496,7 @@ xmlRegisterDefaultInputCallbacks
  * Registers the default compiled-in I/O handlers.
  */
 void
-#ifdef VMS
-xmlRegisterDefOutputCallbacks
-#else
 xmlRegisterDefaultOutputCallbacks
-#endif
 (void) {
     if (xmlOutputCallbackInitialized)
 	return;
@@ -1537,7 +1530,7 @@ xmlRegisterDefaultOutputCallbacks
 
 #ifdef LIBXML_HTTP_ENABLED
 /**
- * xmlRegisterHTTPPostCallbacks
+ * xmlRegisterHTTPPostCallbacks:
  *
  * By default, libxml submits HTTP output requests using the "PUT" method.
  * Calling this method changes the HTTP output method to use the "POST"
@@ -1706,8 +1699,6 @@ xmlOutputBufferClose(xmlOutputBufferPtr out) {
  * @URI:  a C string containing the URI or filename
  * @enc:  the charset encoding if known
  *
- * VMS version of xmlParserInputBufferCreateFilename()
- *
  * Returns the new parser input or NULL
  */
 /**
@@ -1724,11 +1715,7 @@ xmlOutputBufferClose(xmlOutputBufferPtr out) {
  * Returns the new parser input or NULL
  */
 xmlParserInputBufferPtr
-#ifdef VMS
-xmlParserInputBufferCreateFname
-#else
 xmlParserInputBufferCreateFilename
-#endif
 (const char *URI, xmlCharEncoding enc) {
     xmlParserInputBufferPtr ret;
     int i = 0;
